@@ -11,9 +11,9 @@ class Auth():
         payload = {'email':email, 'provider':provider}
         return requests.post('{0}/loginCustomer'.format(base_url), data=payload, headers=headers)
 
-    def getAccessTokenByPhone(self, phone, provider):
+    def getAccessTokenByPhone(self, phone, provider, otpCode):
         headers = {'authorization':self.__apiKey}
-        payload = {'phone':phone, 'provider':provider}
+        payload = {'phone':phone, 'provider':provider, 'otpCode':otpCode}
         return requests.post('{0}/loginCustomer'.format(base_url), data=payload, headers=headers)
 
     def linkPhoneToEmail(self, phone, token):
