@@ -6,7 +6,7 @@ from quickey_python_sdk.app import App
 class QuickeySDK:
     def __init__(self, apiKey):
         self.app = App(apiKey)
-        self.auth = Auth()
+        self.auth = Auth(apiKey)
 
 class QuickeySDKError:
     def __init__(self):
